local Module = LibStub("AceAddon-3.0"):NewAddon("LH_SoundDevice")

local LDB = LibStub("LibDataBroker-1.1", true)
local LDBIcon = LibStub("LibDBIcon-1.0", true)

function Module:OnInitialize()
    self.db = LibStub("AceDB-3.0"):New("LH_SoundDeviceDB", {
        profile = {
            minimapIcon = {},
            hideMinimapOption = nil
        }
    })

    local LDBObj = LDB:NewDataObject("Little Helper: Audio Device",  {
        type = "data source",
        text = "Sound!",
        icon = [[Interface\Icons\inv_misc_ear_nightelf_01]],
        OnClick = function () self:ShowMenu() end,
        OnTooltipShow = function (tooltip) self:ShowTooltip(tooltip) end})

    LDBIcon:Register("Audio Device", LDBObj, self.db.profile.minimapIcon)
end

function Module:ShowMenu ()
    self.menuFrame = self.menuFrame or CreateFrame("Frame", "LH_SoundDevice3", UIParent, "UIDropDownMenuTemplate")
    local menuTable = {}

    menuTable[#menuTable+1] = { text = "Select Audio Device",  notCheckable = true, isTitle = true }

    for i=1, Sound_GameSystem_GetNumOutputDrivers()-1 do 
        table.insert( menuTable, {
            func = function () self:SelectedSoundDevide(i) end,
            text = Sound_GameSystem_GetOutputDriverNameByIndex(i), 
            checked = self:IsSoundDeviceSelected(i)
        })
     end 

     if self.db.profile.hideMinimapOption ~= true then
        menuTable[#menuTable+1] = { text = "Minimap Icon",  notCheckable = true, isTitle = true }

        table.insert( menuTable, {
           func = function () 
                LDBIcon:Hide("Audio Device")
                self.db.profile.minimapIcon.hide = not self.db.profile.minimapIcon.hide
                if self.db.profile.minimapIcon.hide then
                    LDBIcon:Hide("Audio Device")
                else
                    LDBIcon:Show("Audio Device")
                end
            end,
           text = "Hide Minimap Icon", 
           checked = self.db.profile.minimapIcon.hide == true
       })
   
       table.insert( menuTable, {
           func = function () self.db.profile.hideMinimapOption = true end,
           text = "Hide 'Minimap Icon' Options", 
           checked = self.db.profile.hideMinimapOption == true
       })
     end

     EasyMenu(menuTable, self.menuFrame, "cursor", 0 , 0, "MENU", 1)
end

function Module:SelectedSoundDevide (index)
    SetCVar("Sound_OutputDriverIndex", index)
    Sound_GameSystem_RestartSoundSystem()
end

function Module:IsSoundDeviceSelected (index)
    return GetCVar("Sound_OutputDriverIndex") == "" .. index
end

function Module:ShowTooltip (tooltip)
    local currentSoundIndex = GetCVar("Sound_OutputDriverIndex")
    local sound = Sound_GameSystem_GetOutputDriverNameByIndex(currentSoundIndex)

    tooltip:AddLine("Little Helper: Audio Device")
    tooltip:AddDoubleLine( "Active", sound, 255,255,255, 255,255,0)
end
